@@ -32,6 +32,7 @@ import uuid
 
 from six import moves
 
+from rally.common.io import junit
 from rally.common import logging
 from rally import exceptions
 
@@ -155,6 +156,7 @@ class RAMInt(object):
             self.__int.value = 0
 
 
+@logging.log_deprecated("it was an inner helper.", rally_version="3.0.0")
 def get_method_class(func):
     """Return the class that defined the given method.
 
@@ -177,6 +179,7 @@ def get_method_class(func):
         return None
 
 
+@logging.log_deprecated("it was an inner helper.", rally_version="3.0.0")
 def first_index(lst, predicate):
     """Return the index of the first element that matches a predicate.
 
@@ -191,27 +194,6 @@ def first_index(lst, predicate):
     return None
 
 
-@logging.log_deprecated(message="Its not used elsewhere in Rally already.",
-                        rally_version="0.4.1")
-def distance(s1, s2):
-    """Computes the edit distance between two strings.
-
-    The edit distance is the Levenshtein distance. The larger the return value,
-    the more edits are required to transform one string into the other.
-
-    :param s1: First string to compare
-    :param s2: Second string to compare
-    :returns: Integer distance between two strings
-    """
-    n = range(0, len(s1) + 1)
-    for y in range(1, len(s2) + 1):
-        l, n = n, [y]
-        for x in moves.range(1, len(s1) + 1):
-            n.append(min(l[x] + 1, n[-1] + 1,
-                         l[x - 1] + (s2[y - 1] != s1[x - 1])))
-    return n[-1]
-
-
 def retry(times, func, *args, **kwargs):
     """Try to execute multiple times function mitigating exceptions.
 
@@ -232,6 +214,7 @@ def retry(times, func, *args, **kwargs):
                 raise
 
 
+@logging.log_deprecated("it is openstack specific.", rally_version="3.0.0")
 def iterate_per_tenants(users):
     """Iterate of a single arbitrary user from each tenant
 
@@ -445,6 +428,7 @@ def make_name_matcher(*names):
     return CustomNameMatcher
 
 
+@logging.log_deprecated("it was an inner helper.", rally_version="3.0.0")
 def merge(length, *sources):
     """Merge lists of lists.
 
@@ -592,7 +576,7 @@ def timeout_thread(queue):
         except (moves.queue.Empty, ValueError):
             # NOTE(rvasilets) Empty means that timeout was occurred.
             # ValueError means that timeout lower than 0.
-            if thread.isAlive():
+            if thread.is_alive():
                 LOG.info("Thread %s is timed out. Terminating." % thread.ident)
                 terminate_thread(thread.ident)
             all_threads.popleft()
@@ -685,28 +669,6 @@ class LockedDict(dict):
         return super(LockedDict, self).clear(*args, **kwargs)
 
 
-def format_float_to_str(num):
-    """Format number into human-readable float format.
-
-     More precise it convert float into the string and remove redundant
-     zeros from the floating part.
-     It will format the number by the following examples:
-     0.0000001 -> 0.0
-     0.000000 -> 0.0
-     37 -> 37.0
-     1.0000001 -> 1.0
-     1.0000011 -> 1.000001
-     1.0000019 -> 1.000002
-
-    :param num: Number to be formatted
-    :return: string representation of the number
-    """
-
-    num_str = "%f" % num
-    float_part = num_str.split(".")[1].rstrip("0") or "0"
-    return num_str.split(".")[0] + "." + float_part
-
-
 class DequeAsQueue(object):
     """Allows to use some of Queue methods on collections.deque."""
 
@@ -829,23 +791,6 @@ class BackupHelper(object):
                 shutil.rmtree(path)
 
 
+@logging.log_deprecated("it was an inner helper.", rally_version="3.0.0")
 def prettify_xml(elem, level=0):
-    """Adds indents.
-
-    Code of this method was copied from
-        http://effbot.org/zone/element-lib.htm#prettyprint
-
-    """
-    i = "\n" + level * "  "
-    if len(elem):
-        if not elem.text or not elem.text.strip():
-            elem.text = i + "  "
-        if not elem.tail or not elem.tail.strip():
-            elem.tail = i
-        for elem in elem:
-            prettify_xml(elem, level + 1)
-        if not elem.tail or not elem.tail.strip():
-            elem.tail = i
-    else:
-        if level and (not elem.tail or not elem.tail.strip()):
-            elem.tail = i
+    return junit._prettify_xml(elem, level=level)
